import React from 'react'
import MainHeading from './MainHeading'

export default { title: 'titles' }

export const mainHeading = () => <MainHeading title='Premium Template Kits' />
export const mainHeadingWithSubtitle = () => <MainHeading title='Premium Template Kits' subtitle='Browse our 100,000 Premium Template Kits' />
