@import '../../../../scss/mixins';

.imageWrapper {
  height: 200px;
  overflow: hidden;
  position: relative;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1);
  padding-bottom: $cardResponsiveImagePadding;

  &:hover {
    .expandButton {
      opacity: 1;
    }
  }
}

.image {
  @include image;
  width: 100%;
}

.expandButton {
  position: absolute;
  bottom: 10px;
  right: 10px;
  opacity: 0;
  transition: opacity 0.2s;
}

.unmetRequirementsMessage {
  @include copy;
}
