@import '../../../../scss/mixins';

.itemCard {
  &:hover {
    .itemDelete {
      opacity: 1;
      transition: opacity ease-in-out 0.4s;
    }
  }
}

.itemImageLink {
  display: block;
  padding-bottom: $cardResponsiveImagePadding;
  overflow: hidden;
  position: relative;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1);
}

.itemImage {
  position: absolute;
  width: 100%;
}

.itemDelete {
  opacity: 0;
  margin: 0 0 0 auto;
}
